SCStreamOutputType

Enum SCStreamOutputType 

#[repr(C)]
pub enum SCStreamOutputType { Screen = 0, Audio = 1, Microphone = 2, }
Type of output received from a capture stream

Used to distinguish between different types of captured data when implementing SCStreamOutputTrait.

Examples

use screencapturekit::stream::output_type::SCStreamOutputType;

fn handle_output(output_type: SCStreamOutputType) {
    match output_type {
        SCStreamOutputType::Screen => println!("Video frame"),
        SCStreamOutputType::Audio => println!("Audio buffer"),
        SCStreamOutputType::Microphone => println!("Microphone audio"),
    }
}

Variants



Screen = 0

Video frame output



Audio = 1

System audio output



Microphone = 2

Microphone audio output (macOS 15.0+)

When using microphone capture, this output type allows separate handling of microphone audio from system audio.